package myextra;

import java.io.Serializable;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.Iterator;
import java.util.List;
import java.util.Map;
import java.util.Map.Entry;
import java.util.SortedSet;
import java.util.TreeSet;
import myextra.DResult;
import myextra.DRow;
import org.gbif.connect.RequestFactory;
import org.gbif.datatester.DataTest;
import org.gbif.datatester.KnownConcepts;
import org.gbif.datatester.RamRecordSet;
import org.gbif.datatester.ResultManager;
import org.gbif.datatester.Tag;
import org.gbif.datatester.TestManager;
import org.gbif.datatester.exception.TestInitializationException;


/**
 * @author     loancea
 */
public class Attributes implements Serializable {
    /**
     *
     */
    private static final long serialVersionUID = 8253936328926000496L;
    private boolean validated = false;

    // fields fulfilled with parameters values
    public String serviceURL = null;

    // is an XML file URL ??
    public boolean isFileURL = false;

    // resource code for DarwinCore & flavors providers
    public String resource = null;

    // requst factory .. the GBIF class wich builds up the request to
    // provider
    public RequestFactory reqFactory = null;

    // flag if we deal with an DarwinCore
    public boolean isDarwinCore = false;

    // filter to restrict the size of the retreived & tested data
    public int conceptId = -1;

    // filter operator
    public int operator = -1;
    public String conceptValue = null;

    // output level
    public Tag.Level level = null;
    private String levelName = "All";
    
    // map (concept id --> factory concept)
    public HashMap<Object, Object> factoryConcepts = null;

    // records gotten from provider
    public List records = null;

    // error list for showErrors()
    // the generics should work on the jvm > 1.5 sun ??
    // public List errorList = new ArrayList();
    public List<String> errorList = new ArrayList<String>();

    // concepts read from configuration file
    public KnownConcepts knownConcepts;

    // list of special concepts with IDs
    public ArrayList<Object> idDefinition = null;

    // record set for the test
    public RamRecordSet recordSet = null;

    // manager that runs the tests
    public TestManager manager = null;

    // request to provider
    public String requestData = null;

    // data from provider
    public String responseData = null;
    public SortedSet<String> selectedTests = new TreeSet<String>();
    ResultManager globalresultmanager = new ResultManager();
    private PagingRetriever pagingthread = null;
    private long lastRetriveTime = 0;
    private long lastProcessingTime = 0;
    private long lastXmlExtracting = 0;
    private int numpages = 0;
    private long totalrecodsretieved = 0;
    private long totalrecordstested = 0 ;
    private long totaltimeretrive = 0;
    private long totaltimeprocessing = 0;
    private long starttestTime =0;

   
    private String formatTag(Tag tag, String value) {
        StringBuffer buffer = new StringBuffer();
        // different color for different level
        buffer.append("<font color=\"");

        if (tag.getLevel() == Tag.Level.FATAL) {
            buffer.append("#990099\">(fatal) ");
        } else if (tag.getLevel() == Tag.Level.ERROR) {
            buffer.append("#FF0000\">(error) ");
        } else if (tag.getLevel() == Tag.Level.WARN) {
            buffer.append("#FF6600\">(warn) ");
        } else if (tag.getLevel() == Tag.Level.INFO) {
            buffer.append("#0000FF\">(info) ");
        } else { // level == DEBUG
            buffer.append("#006666\">(debug) ");
        }

        // tag name
        buffer.append(tag.getName());

        // tag value
        if ((value != null) && (value.length() > 0)) {
            buffer.append(": [" + value + "]");
        }

        buffer.append("</font>");

        return buffer.toString();
    }

    private String getFormatTag(Tag tag, String value) {
        StringBuffer buffer = new StringBuffer();
        // different color for different level
        buffer.append("<font color=\"");

        if (tag.getLevel() == Tag.Level.FATAL) {
            buffer.append("#990099\">(fatal) ");
        } else if (tag.getLevel() == Tag.Level.ERROR) {
            buffer.append("#FF0000\">(error) ");
        } else if (tag.getLevel() == Tag.Level.WARN) {
            buffer.append("#FF6600\">(warn) ");
        } else if (tag.getLevel() == Tag.Level.INFO) {
            buffer.append("#0000FF\">(info) ");
        } else { // level == DEBUG
            buffer.append("#006666\">(debug) ");
        }

        // tag name
        buffer.append(tag.getName());

        // tag value
        if ((value != null) && (value.length() > 0)) {
            buffer.append(": [" + value + "]");
        }

        buffer.append("</font>");

        return buffer.toString();
    }

    private String getFormatTag(Tag tag) {
        StringBuffer buffer = new StringBuffer();
        // different color for different level
        buffer.append("<font color=\"");

        if (tag.getLevel() == Tag.Level.FATAL) {
            buffer.append("#990099\">(fatal) ");
        } else if (tag.getLevel() == Tag.Level.ERROR) {
            buffer.append("#FF0000\">(error) ");
        } else if (tag.getLevel() == Tag.Level.WARN) {
            buffer.append("#FF6600\">(warn) ");
        } else if (tag.getLevel() == Tag.Level.INFO) {
            buffer.append("#0000FF\">(info) ");
        } else { // level == DEBUG
            buffer.append("#006666\">(debug) ");
        }

        String value = "aaaaa";
        // tag name
        buffer.append(tag.getName());

        // tag value
        if ((value != null) && (value.length() > 0)) {
            buffer.append(": [" + value + "]");
        }

        buffer.append("</font>");

        return buffer.toString();
    }

    public int getRecordsRetrived() {
        if (records == null) {
            return 0;
        } else {
            return records.size();
        }
    }


    /**
     * @return the globalresultmanager
     */
    public ResultManager getGlobalmanager() {
        return globalresultmanager;
    }

    /**
     * @return the manager
     */
    public TestManager getManager() {
        return manager;
    }

    /**
     * @return the pagingthread
     */
    public PagingRetriever getPagingthread() {
        return pagingthread;
    }

    /**
     * @param pagingthread
     *            the pagingthread to set
     */
    public void setPagingthread(PagingRetriever pagingthread) {
        this.pagingthread = pagingthread;
    }

    /**
     * @return the errorList
     */
    public List<String> getErrorList() {
        return errorList;
    }

    /**
     * @param errorList
     *            the errorList to set
     */
    public void setErrorList(List<String> errorList) {
        this.errorList = errorList;
    }

    /**
     * @return the validated
     */
    public boolean isValidated() {
        return validated;
    }

    /**
     * @param validated
     *            the validated to set
     */
    public void setValidated(boolean validated) {
        this.validated = validated;
    }

    public String getRequeststring() {
        return responseData;
    }

    public boolean isPagingthreadrunning() {
        boolean _isThreadRunning = false;

        if (this.pagingthread != null) {
            _isThreadRunning = pagingthread.isAlive();
        }

        ;

        // return _isThreadRunning;
        return true;
    }

    public boolean isPagingthreadNotrunning() {
        boolean _isThreadRunning = false;

        if (this.pagingthread != null) {
            _isThreadRunning = pagingthread.isAlive();
        }

        ;

        return !_isThreadRunning;
    }

    /**
     * @return the lastRetriveTime
     */
    public long getLastRetriveTime() {
        return lastRetriveTime;
    }

    /**
     * @param lastRetriveTime
     *            the lastRetriveTime to set
     */
    public void setLastRetriveTime(long lastRetriveTime) {
        this.lastRetriveTime = lastRetriveTime;
    }

    /**
     * @return the lastProcessingTime
     */
    public long getLastProcessingTime() {
        return lastProcessingTime;
    }

    /**
     * @param lastProcessingTime
     *            the lastProcessingTime to set
     */
    public void setLastProcessingTime(long lastProcessingTime) {
        this.lastProcessingTime = lastProcessingTime;
    }

    /**
     * @return the lastXmlExtracting
     */
    public long getLastXmlExtracting() {
        return lastXmlExtracting;
    }

    /**
     * @param lastXmlExtracting
     *            the lastXmlExtracting to set
     */
    public void setLastXmlExtracting(long lastXmlExtracting) {
        this.lastXmlExtracting = lastXmlExtracting;
    }

    /**
     * @return the numpages
     */
    public int getNumpages() {
        return numpages;
    }

    /**
     * @param numpages
     *            the numpages to set
     */
    public void setNumpages(int numpages) {
        this.numpages = numpages;
    }

    public int getUpdateinterval() {
        int rez = 0;

        if (pagingthread != null) {
            if (pagingthread.isAlive()) {
                rez = 10000;

                //sau parametru 
            }
        }

        return rez;
    }

    public String getUpdatestatus() {
        String status = "Done";

        if (pagingthread != null) {
            if (pagingthread.isAlive()) {
                status = "Working ... Please ..Wait !";
            }
        }

        return status;
    }

    /**
     * @return the responseData
     */
    public String getResponseData() {
        return responseData;
    }

    /**
     * @param responseData the responseData to set
     */
    public void setResponseData(String responseData) {
        this.responseData = responseData;
    }

	/**
	 * @return the levelName
	 */
	public String getLevelName() {
		return levelName;
	}

	/**
	 * @param levelName the levelName to set
	 */
	public void setLevelName(String levelName) {
		this.levelName = levelName;
	}

	/**
	 * @return the totalrecodsretieved
	 */
	public long getTotalrecodsretieved() {
		return totalrecodsretieved;
	}

	/**
	 * @param totalrecodsretieved the totalrecodsretieved to set
	 */
	public void setTotalrecodsretieved(long totalrecodsretieved) {
		this.totalrecodsretieved = totalrecodsretieved;
	}

	/**
	 * @return the totalrecordstested
	 */
	public long getTotalrecordstested() {
		return totalrecordstested;
	}

	/**
	 * @param totalrecordstested the totalrecordstested to set
	 */
	public void setTotalrecordstested(long totalrecordstested) {
		this.totalrecordstested = totalrecordstested;
	}

	/**
	 * @return the totaltimeretrive
	 */
	public long getTotaltimeretrive() {
		return totaltimeretrive;
	}

	/**
	 * @param totaltimeretrive the totaltimeretrive to set
	 */
	public void setTotaltimeretrive(long totaltimeretrive) {
		this.totaltimeretrive = totaltimeretrive;
	}

	/**
	 * @return the totaltimeprocessing
	 */
	public long getTotaltimeprocessing() {
		return totaltimeprocessing;
	}

	/**
	 * @param totaltimeprocessing the totaltimeprocessing to set
	 */
	public void setTotaltimeprocessing(long totaltimeprocessing) {
		this.totaltimeprocessing = totaltimeprocessing;
	}

	/**
	 * @return the starttestTime
	 */
	public long getStarttestTime() {
		return starttestTime;
	}

	/**
	 * @param starttestTime the starttestTime to set
	 */
	public void setStarttestTime(long starttestTime) {
		this.starttestTime = starttestTime;
	}
}
