package myextra;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.HashSet;
import java.util.Iterator;
import java.util.Map;
import java.util.Set;
import myextra.Controller;
import org.apache.log4j.Logger;
import org.gbif.connect.Concept;
import org.gbif.connect.ConnectionException;
import org.gbif.connect.SODetailRecord;
import org.gbif.datatester.RamRecord;
import org.gbif.datatester.RamRecordSet;
import org.gbif.datatester.Tag;
import org.gbif.datatester.TestManager;
import org.gbif.datatester.XmlRecordSet;
import org.gbif.datatester.exception.ConceptNotFoundException;
import org.gbif.datatester.exception.RecordSetException;
import org.gbif.datatester.exception.TestConfigurationException;
import org.gbif.datatester.exception.TestInitializationException;
import org.gbif.datatester.exception.TestProcessingException;
import org.gbif.datatester.exception.UnableToLoadConceptsException;
import org.jdom.Document;
import org.jdom.Element;


/**
 * @author     loancea
 */
public class FileTestExecutor extends Thread {
    private Attributes attr = null;
    private Logger logger = null;
    private Controller controller;

    public FileTestExecutor(Logger _logger, Attributes _attr,
        Controller _controller) {
        this.logger = _logger;
        this.attr = _attr;
        this.controller = _controller;
    }

    @Override
    public synchronized void run() {
        logger.info("Runnig tests");
        // create test manager
        // run tests
        Tag.setLevelThreshold(attr.level);
/*
        try {
                    attr.knownConcepts);
            attr.manager.getPossibleTests( reocrds set
           );

            XmlRecordSet xmlrecordsset = new XmlRecordSet();
            createRecordSet(attr, null);
            attr.manager.test(attr.recordSet, attr.selectedTests);
        } catch (TestConfigurationException e) {
            TODO Auto-generated catch block
            e.printStackTrace();
        } catch (TestInitializationException e) {
            TODO Auto-generated catch block
            e.printStackTrace();
        }
 */
    }

    private void createRecordSet(Attributes attr, String tomcatPath)
        throws ConnectionException, UnableToLoadConceptsException,
            ConceptNotFoundException, RecordSetException {
        org.gbif.datatester.Concept c_catalogNumber = attr.knownConcepts.getConcept(
                "CatalogNumber");
        org.gbif.datatester.Concept c_scientificName = attr.knownConcepts.getConcept(
                "ScientificName");
        org.gbif.datatester.Concept c_subspecies = attr.knownConcepts.getConcept(
                "Subspecies");
        org.gbif.datatester.Concept c_species = attr.knownConcepts.getConcept(
                "Species");
        org.gbif.datatester.Concept c_genus = attr.knownConcepts.getConcept(
                "Genus");
        org.gbif.datatester.Concept c_family = attr.knownConcepts.getConcept(
                "Family");
        org.gbif.datatester.Concept c_author = attr.knownConcepts.getConcept(
                "Author");
        org.gbif.datatester.Concept c_country = attr.knownConcepts.getConcept(
                "Country");
        org.gbif.datatester.Concept c_latitude = attr.knownConcepts.getConcept(
                "Latitude");
        org.gbif.datatester.Concept c_longitude = attr.knownConcepts.getConcept(
                "Longitude");
        org.gbif.datatester.Concept c_institutionCode = attr.knownConcepts.getConcept(
                "InstitutionCode");
        org.gbif.datatester.Concept c_collectionCode = attr.knownConcepts.getConcept(
                "CollectionCode");
        org.gbif.datatester.Concept c_collectionDate = attr.knownConcepts.getConcept(
                "CollectionDate");
        org.gbif.datatester.Concept c_collectionDay = attr.knownConcepts.getConcept(
                "CollectionDay");
        org.gbif.datatester.Concept c_collectionMonth = attr.knownConcepts.getConcept(
                "CollectionMonth");
        org.gbif.datatester.Concept c_collectionYear = attr.knownConcepts.getConcept(
                "CollectionYear");
        org.gbif.datatester.Concept c_recordBasis = attr.knownConcepts.getConcept(
                "RecordBasis");

        // Added ABCD 2.06
        org.gbif.datatester.Concept c_higherTaxonRank = attr.knownConcepts.getConcept(
                "HigherTaxonRank");

        // org.gbif.datatester.Concept c_higherTaxa = attr.knownConcepts
        // .getConcept("HigherTaxa");
        org.gbif.datatester.Concept c_ISO3166Code = attr.knownConcepts.getConcept(
                "ISO3166Code");

        // org.gbif.datatester.Concept c_Title = attr.knownConcepts
        // .getConcept("Title");

        // record id
        attr.idDefinition = new ArrayList<Object>();

        if (attr.isDarwinCore) {
            attr.idDefinition.add(c_institutionCode);
            attr.idDefinition.add(c_collectionCode);
        }

        attr.idDefinition.add(c_catalogNumber);
        attr.idDefinition.add(c_scientificName);

        // list of used concepts
        Set<org.gbif.datatester.Concept> usedConcepts = new HashSet<org.gbif.datatester.Concept>();
        usedConcepts.add(c_catalogNumber);
        usedConcepts.add(c_scientificName);
        usedConcepts.add(c_subspecies);
        usedConcepts.add(c_species);
        usedConcepts.add(c_genus);
        usedConcepts.add(c_family);
        usedConcepts.add(c_author);
        usedConcepts.add(c_country);
        usedConcepts.add(c_latitude);
        usedConcepts.add(c_longitude);
        usedConcepts.add(c_institutionCode);
        usedConcepts.add(c_collectionCode);
        usedConcepts.add(c_collectionDate);
        usedConcepts.add(c_collectionDay);
        usedConcepts.add(c_collectionMonth);
        usedConcepts.add(c_collectionYear);
        usedConcepts.add(c_recordBasis);

        // added ABCD 2.06
        usedConcepts.add(c_higherTaxonRank);
        // usedConcepts.add(c_higherTaxa);
        usedConcepts.add(c_ISO3166Code);
        // usedConcepts.add(c_Title);

        // instantiate RAM record set
        attr.recordSet = new RamRecordSet(usedConcepts);

        for (Iterator it = attr.records.iterator(); it.hasNext();) {
            SODetailRecord record = (SODetailRecord) it.next();
            Map m = new HashMap();
            Concept c = (Concept) attr.factoryConcepts.get(new Integer(
                        Concept.ID_CATALOGNUMBER));
            m.put(c_catalogNumber, (c == null) ? null : record.get(c.getPath()));
            c = (Concept) attr.factoryConcepts.get(new Integer(
                        Concept.ID_SCIENTIFICNAME));

            m.put(c_scientificName, (c == null) ? null : record.get(c.getPath()));

            // logger.info("scientific name :"+ record.get(c.getPath()));
            c = (Concept) attr.factoryConcepts.get(new Integer(
                        Concept.ID_SUBSPECIES));
            m.put(c_subspecies, (c == null) ? null : record.get(c.getPath()));
            c = (Concept) attr.factoryConcepts.get(new Integer(
                        Concept.ID_SPECIES));
            m.put(c_species, (c == null) ? null : record.get(c.getPath()));
            c = (Concept) attr.factoryConcepts.get(new Integer(Concept.ID_GENUS));
            m.put(c_genus, (c == null) ? null : record.get(c.getPath()));
            c = (Concept) attr.factoryConcepts.get(new Integer(
                        Concept.ID_FAMILY));
            m.put(c_family, (c == null) ? null : record.get(c.getPath()));
            c = (Concept) attr.factoryConcepts.get(new Integer(
                        Concept.ID_AUTHOR));
            m.put(c_author, (c == null) ? null : record.get(c.getPath()));
            c = (Concept) attr.factoryConcepts.get(new Integer(
                        Concept.ID_COUNTRY));

            // System.out.println("Country Name: "+ record.get(c.getPath()));
            m.put(c_country, (c == null) ? null : record.get(c.getPath()));
            c = (Concept) attr.factoryConcepts.get(new Integer(
                        Concept.ID_LATITUDE));

            String v = record.get(c.getPath());
            m.put(c_latitude,
                (v == null) ? null : new Double(v.replace(',', '.')));
            c = (Concept) attr.factoryConcepts.get(new Integer(
                        Concept.ID_LONGITUDE));
            v = record.get(c.getPath());
            m.put(c_longitude,
                (v == null) ? null : new Double(v.replace(',', '.')));
            c = (Concept) attr.factoryConcepts.get(new Integer(
                        Concept.ID_INSTITUTIONCODE));
            m.put(c_institutionCode,
                (c == null) ? null : record.get(c.getPath()));
            c = (Concept) attr.factoryConcepts.get(new Integer(
                        Concept.ID_COLLECTIONCODE));
            m.put(c_collectionCode, (c == null) ? null : record.get(c.getPath()));
            c = (Concept) attr.factoryConcepts.get(new Integer(
                        Concept.ID_COLLECTIONDATE));
            m.put(c_collectionDate, (c == null) ? null : record.get(c.getPath()));
            c = (Concept) attr.factoryConcepts.get(new Integer(
                        Concept.ID_COLLECTIONDAY));
            m.put(c_collectionDay, (c == null) ? null : record.get(c.getPath()));
            c = (Concept) attr.factoryConcepts.get(new Integer(
                        Concept.ID_COLLECTIONMONTH));
            m.put(c_collectionMonth,
                (c == null) ? null : record.get(c.getPath()));
            c = (Concept) attr.factoryConcepts.get(new Integer(
                        Concept.ID_COLLECTIONYEAR));
            m.put(c_collectionYear, (c == null) ? null : record.get(c.getPath()));
            c = (Concept) attr.factoryConcepts.get(new Integer(
                        Concept.ID_RECORDBASIS));
            m.put(c_recordBasis, (c == null) ? null : record.get(c.getPath()));

            // added ABCD2.06
            c = (Concept) attr.factoryConcepts.get(new Integer(201));

            m.put(c_higherTaxonRank,
                (c == null) ? null
                            : record.get(
                    "Unit/Identifications/Identification/Result/TaxonIdentified/HigherTaxa/HigherTaxon/HigherTaxonRank"));

            // System.out.println("HigerTaxonRank:"+
            // record.get("Unit/Identifications/Identification/Result/TaxonIdentified/HigherTaxa/HigherTaxon/HigherTaxonRank"));
            c = (Concept) attr.factoryConcepts.get(new Integer(200));
            m.put(c_ISO3166Code,
                (c == null) ? null
                            : record.get("Unit/Gathering" +
                    c.getPath().replaceFirst(".", "")));

            // System.out.println("ISO code:"+ c.getPath());
            // System.out.println("iso code: "+
            // record.get("Unit/Gathering"+c.getPath().replaceFirst(".","")));

            // c = (Concept) attr.factoryConcepts.get(new Integer(
            // ABCDConcept.ID_METADATA_CODE));
            // System.out.println("Title: "+ record.get(c.getPath()));
            // m.put(c_recordBasis, (c == null) ? null :
            // record.get(c.getPath()));
            attr.recordSet.addRecord(new RamRecord(attr.idDefinition, m));
        }
    }
}
