package myextra;

import java.io.File;
import java.io.FileNotFoundException;
import java.io.FileOutputStream;
import java.io.IOException;
import java.io.PrintStream;
import java.io.UnsupportedEncodingException;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.HashSet;
import java.util.Iterator;
import java.util.List;
import java.util.Map;
import java.util.Properties;
import java.util.Set;
import javax.faces.context.FacesContext;
import javax.mail.Address;
import javax.mail.Message;
import javax.mail.MessagingException;
import javax.mail.Session;
import javax.mail.Transport;
import javax.mail.internet.AddressException;
import javax.mail.internet.InternetAddress;
import javax.mail.internet.MimeMessage;
import myextra.Controller;
import myextra.DResult;
import myextra.DRow;
import org.apache.log4j.Logger;
import org.gbif.connect.Concept;
import org.gbif.connect.ConnectionException;
import org.gbif.connect.ConnectionPool;
import org.gbif.connect.Request;
import org.gbif.connect.Response;
import org.gbif.connect.SODetailRecord;
import org.gbif.connect.SODetailRequest;
import org.gbif.datatester.AssignedTag;
import org.gbif.datatester.RamRecord;
import org.gbif.datatester.RamRecordSet;
import org.gbif.datatester.ResultManager;
import org.gbif.datatester.Target;
import org.gbif.datatester.exception.ConceptNotFoundException;
import org.gbif.datatester.exception.RecordSetException;
import org.gbif.datatester.exception.TestProcessingException;
import org.gbif.datatester.exception.UnableToLoadConceptsException;

/**
 * PageRetriever
 * 
 * @see Thread
 * @author loancea
 */
public class PagingRetriever extends Thread {
	/**
	 * Number of Record that a page should contain
	 * 
	 */
	private int pageSize = 0;
	private int startRecord = 0;
	private Attributes attr = null;
	private Logger logger = null;
	private ArrayList<String> list = null;
	private String tomcatPath = null;
	private File fileTestsResults;
	private String fileName = "";
	private String fileURL = "";
	private String emailAddress = "";
	private Map pageResults = new HashMap();
	private Controller controller;

	/**
	 * Constructor
	 * 
	 * @param pageSize
	 */
	public PagingRetriever(Attributes _attr, int _pageSize, Logger _logger,
			ArrayList<String> _list, Controller _testcontroller,
			String _EmailAddress, String _filename, String _fileUrl) {
		super();
		this.controller = _testcontroller;
		this.fileName = _filename;
		this.fileURL = _fileUrl;
		this.pageSize = _pageSize;
		this.attr = _attr;
		this.logger = _logger;
		this.list = _list;
		this.emailAddress = _EmailAddress;
		
		if (controller.isCodevalidated() && controller.getEmailaddress() != "") {
			try {
				FacesContext facesContext = FacesContext.getCurrentInstance();
				String resultsdir = facesContext.getExternalContext()
						.getInitParameter("resultsdir");
				// test if the directory exits , if not create
				File parentDir = new File(resultsdir);
				if (parentDir.mkdirs()) {
					logger.info("Results file path created");
				};
				fileTestsResults = new File(resultsdir + fileName);
				
				PrintStream ps = new PrintStream(fileTestsResults);
				ps.println("TestId;TestDesc;");
				// ps.close();
			} catch (FileNotFoundException e1) {
				// TODO Auto-generated catch block
				e1.printStackTrace();
				logger.error("results file !! ");
				logger.error(e1.getMessage());
			}
		}
		
	}

	@Override
	public void interrupt() {
		super.interrupt();
	}

	@Override
	public boolean isInterrupted() {
		return super.isInterrupted();
	}

	@Override
	public void run() {
		attr.setLastProcessingTime(0);
		attr.setLastRetriveTime(0);
		attr.setLastXmlExtracting(0);
		attr.setNumpages(0);

		long startPageRetrieve = System.currentTimeMillis();
		long endPageRetrieve = startPageRetrieve;
		long startXmlExtracting = startPageRetrieve;
		long endXmlExtracting = startPageRetrieve;
		long startPageRecordsTesting = startPageRetrieve;
		long endPageRecordsTesting = startPageRetrieve;

		try {
			// Metadata Requst
			SODetailRequest detailrequest;
			detailrequest = attr.reqFactory.createSODetailRequest(0,
					attr.serviceURL, Request.TIMEOUT_NONE,
					Request.PRIORITY_NORMAL, attr.resource, attr.conceptId,
					attr.conceptValue, attr.operator);
			detailrequest.setLimit(pageSize);
			detailrequest.setResponseConcepts(list);

			String xmlrecreq;
			ConnectionPool pool = ConnectionPool.getConnectionPool("demo");

			do {
				startPageRetrieve = System.currentTimeMillis();
				xmlrecreq = detailrequest.getXmlRequestString();
				xmlrecreq = xmlrecreq.replaceFirst("start=\"0\"", "start=\""
						+ startRecord + "\"");
				detailrequest.setXmlRequestString(xmlrecreq);
				attr.requestData = detailrequest.getXmlRequestString();

				if (startRecord > 0) {
					detailrequest.prepareForMoreRecords();
				}

				pool.submit(detailrequest);
				detailrequest.waitForResponse();
				endPageRetrieve = System.currentTimeMillis();
				logger.info("Got Records in : "
						+ (endPageRetrieve - startPageRetrieve) + " ms");
				attr.setLastRetriveTime(endPageRetrieve - startPageRetrieve);

				Response detailresponse = detailrequest.getResponse();

				if (detailresponse == null) {
					attr.errorList.add("No response from provider");
				}

				attr.responseData = detailresponse.getXmlResponseString();

				String error = detailresponse
						.getProcessingErrors(Response.SEVERITY_FATAL);

				if (error != null) {
					attr.errorList.add("Error from provider: " + error);
				}

				startXmlExtracting = System.currentTimeMillis();
				attr.records = detailresponse.getRecords();

				if (attr.records.isEmpty()) {
					attr.errorList
							.add("No records retrieved from the provider (use another filter)");
					attr.errorList.add(detailresponse.getXmlResponseString());
				} else {
					attr.setNumpages(attr.getNumpages() + 1);

					// this.testcontroller.SetAttr(this.attr);
					try {
						createRecordSet(attr, this.tomcatPath);
						endXmlExtracting = System.currentTimeMillis();
						logger.info("Extracted " + attr.records.size()
								+ " Records in : "
								+ (endXmlExtracting - startXmlExtracting)
								+ " ms");
						attr.setLastXmlExtracting(endXmlExtracting
								- startXmlExtracting);
						startPageRecordsTesting = System.currentTimeMillis();
						attr.manager.test(attr.recordSet, controller
								.getSelectedtestids());
						endPageRecordsTesting = System.currentTimeMillis();
						pageResults = attr.manager.getResults();
						saveResultstoFile();
						logger
								.info("Tested "
										+ attr.records.size()
										+ " records in : "
										+ (endPageRecordsTesting - startPageRecordsTesting)
										+ " ms");
						attr.setLastProcessingTime(endPageRecordsTesting
								- startPageRecordsTesting);
					} catch (UnableToLoadConceptsException e) {
						logger.error(e.getMessage());
						e.printStackTrace();
					} catch (ConceptNotFoundException e) {
						logger.error(e.getMessage());
						e.printStackTrace();
					} catch (RecordSetException e) {
						logger.error(e.getMessage());
						e.printStackTrace();
					} catch (TestProcessingException e) {
						logger.error(e.getMessage());
						e.printStackTrace();
					} catch (FileNotFoundException e) {
						logger.error(e.getMessage());
						e.printStackTrace();
					}
				}

				startRecord = startRecord + pageSize;
			} while (!detailrequest.atEndOfRecords() && !controller.isOnepage());

			if (this.attr.isValidated()
					&& ((emailAddress != null) || (emailAddress.length() > 1))
					&& ((attr.records != null) || (attr.records.size() > 0))) {
				sendNotofcationEmail();
			}
		} catch (ConnectionException e) {
			e.printStackTrace();
		}
	}

	@Override
	public void start() {
		super.start();
	}

	// ------------------------------------------------------------------
	private void createRecordSet(Attributes attr, String tomcatPath)
			throws ConnectionException, UnableToLoadConceptsException,
			ConceptNotFoundException, RecordSetException {
		org.gbif.datatester.Concept c_catalogNumber = attr.knownConcepts
				.getConcept("CatalogNumber");
		org.gbif.datatester.Concept c_scientificName = attr.knownConcepts
				.getConcept("ScientificName");
		org.gbif.datatester.Concept c_subspecies = attr.knownConcepts
				.getConcept("Subspecies");
		org.gbif.datatester.Concept c_species = attr.knownConcepts
				.getConcept("Species");
		org.gbif.datatester.Concept c_genus = attr.knownConcepts
				.getConcept("Genus");
		org.gbif.datatester.Concept c_family = attr.knownConcepts
				.getConcept("Family");
		org.gbif.datatester.Concept c_author = attr.knownConcepts
				.getConcept("Author");
		org.gbif.datatester.Concept c_country = attr.knownConcepts
				.getConcept("Country");
		org.gbif.datatester.Concept c_latitude = attr.knownConcepts
				.getConcept("Latitude");
		org.gbif.datatester.Concept c_longitude = attr.knownConcepts
				.getConcept("Longitude");
		org.gbif.datatester.Concept c_institutionCode = attr.knownConcepts
				.getConcept("InstitutionCode");
		org.gbif.datatester.Concept c_collectionCode = attr.knownConcepts
				.getConcept("CollectionCode");
		org.gbif.datatester.Concept c_collectionDate = attr.knownConcepts
				.getConcept("CollectionDate");
		org.gbif.datatester.Concept c_collectionDay = attr.knownConcepts
				.getConcept("CollectionDay");
		org.gbif.datatester.Concept c_collectionMonth = attr.knownConcepts
				.getConcept("CollectionMonth");
		org.gbif.datatester.Concept c_collectionYear = attr.knownConcepts
				.getConcept("CollectionYear");
		org.gbif.datatester.Concept c_recordBasis = attr.knownConcepts
				.getConcept("RecordBasis");

		// Added ABCD 2.06
		org.gbif.datatester.Concept c_higherTaxonRank = attr.knownConcepts
				.getConcept("HigherTaxonRank");

		// org.gbif.datatester.Concept c_higherTaxa = attr.knownConcepts
		// .getConcept("HigherTaxa");
		org.gbif.datatester.Concept c_ISO3166Code = attr.knownConcepts
				.getConcept("ISO3166Code");

		// org.gbif.datatester.Concept c_Title = attr.knownConcepts
		// .getConcept("Title");

		// record id
		attr.idDefinition = new ArrayList<Object>();

		if (attr.isDarwinCore) {
			attr.idDefinition.add(c_institutionCode);
			attr.idDefinition.add(c_collectionCode);
		}

		attr.idDefinition.add(c_catalogNumber);
		attr.idDefinition.add(c_scientificName);

		// list of used concepts
		Set<org.gbif.datatester.Concept> usedConcepts = new HashSet<org.gbif.datatester.Concept>();
		usedConcepts.add(c_catalogNumber);
		usedConcepts.add(c_scientificName);
		usedConcepts.add(c_subspecies);
		usedConcepts.add(c_species);
		usedConcepts.add(c_genus);
		usedConcepts.add(c_family);
		usedConcepts.add(c_author);
		usedConcepts.add(c_country);
		usedConcepts.add(c_latitude);
		usedConcepts.add(c_longitude);
		usedConcepts.add(c_institutionCode);
		usedConcepts.add(c_collectionCode);
		usedConcepts.add(c_collectionDate);
		usedConcepts.add(c_collectionDay);
		usedConcepts.add(c_collectionMonth);
		usedConcepts.add(c_collectionYear);
		usedConcepts.add(c_recordBasis);

		// added ABCD 2.06
		usedConcepts.add(c_higherTaxonRank);
		// usedConcepts.add(c_higherTaxa);
		usedConcepts.add(c_ISO3166Code);
		// usedConcepts.add(c_Title);

		// instantiate RAM record set
		attr.recordSet = new RamRecordSet(usedConcepts);

		for (Iterator it = attr.records.iterator(); it.hasNext();) {
			SODetailRecord record = (SODetailRecord) it.next();
			Map<org.gbif.datatester.Concept, Comparable> m = new HashMap<org.gbif.datatester.Concept, Comparable>();
			Concept c = (Concept) attr.factoryConcepts.get(new Integer(
					Concept.ID_CATALOGNUMBER));
			m
					.put(c_catalogNumber, (c == null) ? null : record.get(c
							.getPath()));
			c = (Concept) attr.factoryConcepts.get(new Integer(
					Concept.ID_SCIENTIFICNAME));

			m.put(c_scientificName, (c == null) ? null : record
					.get(c.getPath()));

			// logger.info("scientific name :"+ record.get(c.getPath()));
			c = (Concept) attr.factoryConcepts.get(new Integer(
					Concept.ID_SUBSPECIES));
			m.put(c_subspecies, (c == null) ? null : record.get(c.getPath()));
			c = (Concept) attr.factoryConcepts.get(new Integer(
					Concept.ID_SPECIES));
			m.put(c_species, (c == null) ? null : record.get(c.getPath()));
			c = (Concept) attr.factoryConcepts
					.get(new Integer(Concept.ID_GENUS));
			m.put(c_genus, (c == null) ? null : record.get(c.getPath()));
			c = (Concept) attr.factoryConcepts.get(new Integer(
					Concept.ID_FAMILY));
			m.put(c_family, (c == null) ? null : record.get(c.getPath()));
			c = (Concept) attr.factoryConcepts.get(new Integer(
					Concept.ID_AUTHOR));
			m.put(c_author, (c == null) ? null : record.get(c.getPath()));
			c = (Concept) attr.factoryConcepts.get(new Integer(
					Concept.ID_COUNTRY));

			// System.out.println("Country Name: "+ record.get(c.getPath()));
			m.put(c_country, (c == null) ? null : record.get(c.getPath()));
			c = (Concept) attr.factoryConcepts.get(new Integer(
					Concept.ID_LATITUDE));

			String v = record.get(c.getPath());
			m.put(c_latitude, (v == null) ? null : new Double(v.replace(',',
					'.')));
			c = (Concept) attr.factoryConcepts.get(new Integer(
					Concept.ID_LONGITUDE));
			v = record.get(c.getPath());
			m.put(c_longitude, (v == null) ? null : new Double(v.replace(',',
					'.')));
			c = (Concept) attr.factoryConcepts.get(new Integer(
					Concept.ID_INSTITUTIONCODE));
			m.put(c_institutionCode, (c == null) ? null : record.get(c
					.getPath()));
			c = (Concept) attr.factoryConcepts.get(new Integer(
					Concept.ID_COLLECTIONCODE));
			m.put(c_collectionCode, (c == null) ? null : record
					.get(c.getPath()));
			c = (Concept) attr.factoryConcepts.get(new Integer(
					Concept.ID_COLLECTIONDATE));
			m.put(c_collectionDate, (c == null) ? null : record
					.get(c.getPath()));
			c = (Concept) attr.factoryConcepts.get(new Integer(
					Concept.ID_COLLECTIONDAY));
			m
					.put(c_collectionDay, (c == null) ? null : record.get(c
							.getPath()));
			c = (Concept) attr.factoryConcepts.get(new Integer(
					Concept.ID_COLLECTIONMONTH));
			m.put(c_collectionMonth, (c == null) ? null : record.get(c
					.getPath()));
			c = (Concept) attr.factoryConcepts.get(new Integer(
					Concept.ID_COLLECTIONYEAR));
			m.put(c_collectionYear, (c == null) ? null : record
					.get(c.getPath()));
			c = (Concept) attr.factoryConcepts.get(new Integer(
					Concept.ID_RECORDBASIS));
			m.put(c_recordBasis, (c == null) ? null : record.get(c.getPath()));

			// added ABCD2.06
			c = (Concept) attr.factoryConcepts.get(new Integer(201));

			m
					.put(
							c_higherTaxonRank,
							(c == null) ? null
									: record
											.get("Unit/Identifications/Identification/Result/TaxonIdentified/HigherTaxa/HigherTaxon/HigherTaxonRank"));

			// System.out.println("HigerTaxonRank:"+
			// record.get("Unit/Identifications/Identification/Result/TaxonIdentified/HigherTaxa/HigherTaxon/HigherTaxonRank"));
			c = (Concept) attr.factoryConcepts.get(new Integer(200));
			m.put(c_ISO3166Code, (c == null) ? null : record
					.get("Unit/Gathering" + c.getPath().replaceFirst(".", "")));

			// System.out.println("ISO code:"+ c.getPath());
			// System.out.println("iso code: "+
			// record.get("Unit/Gathering"+c.getPath().replaceFirst(".","")));

			// c = (Concept) attr.factoryConcepts.get(new Integer(
			// ABCDConcept.ID_METADATA_CODE));
			// System.out.println("Title: "+ record.get(c.getPath()));
			// m.put(c_recordBasis, (c == null) ? null :
			// record.get(c.getPath()));
			attr.recordSet.addRecord(new RamRecord(attr.idDefinition, m));
		}
	}

	private void saveResultstoFile() throws FileNotFoundException {
		// Open the file and then get a channel from the stream
		PrintStream ps = new PrintStream(fileTestsResults);

		

		Map<String, String> alltests = attr.manager.getAllTests();
		Iterator pageResultsi = pageResults.entrySet().iterator();

		while (pageResultsi.hasNext()) {
			Map.Entry<String, ResultManager> me = (Map.Entry<String, ResultManager>) pageResultsi
					.next();
			String key = me.getKey();
			ResultManager resultManager = me.getValue();

			Map targetmap = resultManager.getTargetIndex();

			if (!targetmap.isEmpty()) {
				Iterator targetmapit = targetmap.entrySet().iterator();

				while (targetmapit.hasNext()) {
					Map.Entry mentry = (Map.Entry) targetmapit.next();
					Target key_target = (Target) mentry.getKey();
					List tar = (List) mentry.getValue();

					for (Iterator it_assignetags = tar.iterator(); it_assignetags
							.hasNext();) {
						AssignedTag atag = (AssignedTag) it_assignetags.next();
						String testid = atag.getTestInstanceId();
						String testdesc = alltests.get(testid);
						Target target = atag.getTarget();

						// search in 
						List<DResult> testsList =  controller.getTestList();
						
						//if (testdesc.indexOf(":") > 0) {
						//	testdesc = testdesc.substring(0, testdesc
						//			.indexOf(":"));
						//}
//						if (testdesc.indexOf("\"") > 0
//								& me.getKey().equalsIgnoreCase("01")) {
//							testdesc = testdesc.substring(0, testdesc
//									.indexOf("\""));
//						}
//						;

						DResult res = null;
						Iterator res_reci = testsList.iterator();
						boolean found = false;

						while (res_reci.hasNext() && !found) {
							DResult cur_res = (DResult) res_reci.next();

							if (cur_res.getTestid().equalsIgnoreCase(
									testid)) {
								found = true;
								res = cur_res;
							}
						}

//						if (!found) {
//							this.attr.results.add(res);
//						}

						res.addErrors(target.getConcepts().length);

						for (int j = 0; j < target.getRecords().length; j++) {
							for (int i = 0; i < target.getConcepts().length; i++) {
								if (res.getRecordsresult() == null) {
									res.setRecordsresult(new ArrayList<DRow>());
								}

								DRow recordsrow = null;

								if (res.getRecordsresult().size() < 200) {
									recordsrow = new DRow();
									res.getRecordsresult().add(recordsrow);
								}

								try {
									StringBuffer text = new StringBuffer();
									text.append(testid + ";");
									testdesc = testdesc.replaceAll("\n", ",");

									if (testdesc.length() < 150) {
										text.append(testdesc + ";");
									} else {
										text.append(testdesc.substring(0, 150)
												+ ";");
									}

									text.append(atag.getTag().getId() + ";");
									text.append(atag.getTag().getName() + ";");
									text.append(atag.getTag().getLevel() + ";");
									text.append(target.getConcepts()[i] + ";");

									if (recordsrow != null) {
										recordsrow.setError(atag.getTag()
												.getName());
										recordsrow.setErrorlevel(atag.getTag()
												.getLevel().toString());
										recordsrow.setConcept((target
												.getConcepts()[i]).getId());
										recordsrow.setConceptvalue(target
												.getRecords()[j]
												.getStringValue(target
														.getConcepts()[i]));
									}

									for (Iterator it2 = attr.idDefinition
											.iterator(); it2.hasNext();) {
										org.gbif.datatester.Concept concept = (org.gbif.datatester.Concept) it2
												.next();
										text.append(target.getRecords()[j]
												.getStringValue(concept)
												+ ";");

										if (concept.getId().equalsIgnoreCase(
												"CatalogNumber")) {
											if (recordsrow != null) {
												recordsrow
														.setUnitID(target
																.getRecords()[j]
																.getStringValue(concept));
											}
										}
									}

									ps.println(text);

									// counters
								} catch (ConceptNotFoundException e) {
									e.printStackTrace();
								}
							}
						}
					}
				}
			}
		}

	}

	private void sendNotofcationEmail() {
		try {
			Properties props = new Properties();

			// props.put("mail.smtp.host", "mySMTPServerHostOrIP");
			Session session = Session.getDefaultInstance(props, null);
			Message emailMessage = new MimeMessage(session);
			props.put("mail.smtp.host", controller.getEmailserver());

			Address biocase = new InternetAddress(controller.getEmailsender(),
					"Quality Checker");

			Address recipient = new InternetAddress(this.emailAddress);
			emailMessage.setFrom(biocase);
			emailMessage.setRecipient(Message.RecipientType.TO, recipient);

			String subject = "Test Results";
			emailMessage.setSubject(subject);

			String content = "Hello, <br/> Here are the results of the tests.<br/>";
			content = content
					+ "You can download the resuls CSV file from following link.<br/> <br/>";
			fileURL = fileURL + "/results/" + fileName;
			content = content + "<a href=\"" + fileURL
					+ "\"> Results file </a> <br/> <br/>";
			content = content + "Have a nice day ! <br/>";
			emailMessage.setContent(content, "text/html");
			Transport.send(emailMessage);
			logger.info("finished to send email to " + emailMessage);
		} catch (UnsupportedEncodingException e) {
			e.printStackTrace();
		} catch (AddressException e) {
			e.printStackTrace();
		} catch (MessagingException e) {
			e.printStackTrace();
		}
	}

	public Attributes getAttr() {
		return attr;
	}
}
